DROP TABLE IF EXISTS emfac2014_ghg_ei_statewide_Phase2;

CREATE TABLE emfac2014_ghg_ei_statewide_Phase2 (index idx (Cal_year, Speed_bin, Model_Year, veh_class, process)) AS 
SELECT *, emission as emission_phase_1, emission as emission_phase2_alt3,emission as emission_phase2_alt4, emission as emission_phase2_FRM, emission as emission_phase2_FRM_wo_trailer,  emission as emission_phase2_FRM_TTGHG2  
from emfac2014_ghg_ei_statewide_no_rule;

#Set VMT for STREX and IDLEX to zero
UPDATE emfac2014_ghg_ei_statewide_Phase2 SET VMT=0 WHERE process in ("IDLEX","STREX");

#Trailer Reductions for Non-Drayage Trucks 
UPDATE emfac2014_ghg_ei_statewide_Phase2 a INNER JOIN trailer_reduction b USING (Cal_Year,Model_Year,Speed_Bin)
SET a.emission             			  = a.emission							*(1-b.TTGHG1),
	a.emission_phase_1     			  = a.emission_phase_1					*(1-b.TTGHG1),
	a.emission_phase2_alt3   		  = a.emission_phase2_alt3				*(1-b.Phase_II_FRM),
	a.emission_phase2_alt4 			  = a.emission_phase2_alt4				*(1-b.Phase_II_FRM),
    a.emission_phase2_FRM  			  = a.emission_phase2_FRM				*(1-b.Phase_II_FRM),
   	a.emission_phase2_FRM_wo_trailer  = a.emission_phase2_FRM_wo_trailer	*(1-b.TTGHG1),
   	a.emission_phase2_FRM_TTGHG2  	  = a.emission_phase2_FRM_TTGHG2		*(1-b.TTGHG2)

WHERE a.Veh_Class in ("T6 CAIRP heavy", "T6 instate heavy", "T6 OOS heavy", "T7 CAIRP", "T7 NNOOS", "T7 NOOS", "T7 tractor") and a.process="RUNEX";

#Trailer Reductions for Drayage Trucks 

UPDATE emfac2014_ghg_ei_statewide_Phase2 a INNER JOIN container_chassis b USING (Model_Year,Speed_Bin)
SET a.emission_phase2_alt3 				= a.emission_phase2_alt3		*(1-b.Phase_II_FRM),
	a.emission_phase2_alt4 				= a.emission_phase2_alt4		*(1-b.Phase_II_FRM),
    a.emission_phase2_FRM  				= a.emission_phase2_FRM			* (1-b.Phase_II_FRM),
    a.emission_phase2_FRM_wo_trailer  	= a.emission_phase2_FRM			*1,
   	a.emission_phase2_FRM_TTGHG2  	  		= a.emission_phase2_FRM_TTGHG2	*(1-b.TTGHG2)
WHERE a.Veh_Class in ("T7 other port","T7 POAK","T7 POLA") and a.process="RUNEX";

# Vehicle Reductions
ALTER TABLE emfac2014_ghg_ei_statewide_phase2 DROP INDEX `idx` , ADD INDEX `idx` (Cal_Year,Veh_Type,Veh_Class,Model_Year,Fuel);

UPDATE emfac2014_ghg_ei_statewide_phase2 a INNER JOIN vehicle_reductions b USING (Veh_Type,Model_Year,Fuel)
SET a.emission             			= a.emission             			* 1, 
	a.emission_phase_1     			= a.emission_phase_1     			* b.Phase_I_Reduction, 
	a.emission_phase2_alt3 			= a.emission_phase2_alt3 			* b.Phase_II_alt3_Reduction,
	a.emission_phase2_alt4 			= a.emission_phase2_alt4 			* b.Phase_II_alt4_Reduction,
    a.emission_phase2_FRM  			= a.emission_phase2_FRM  			* b.Phase_II_FRM_Reduction,
    a.emission_phase2_FRM_wo_trailer= a.emission_phase2_FRM_wo_trailer	* b.Phase_II_FRM_Reduction,
    a.emission_phase2_FRM_TTGHG2  	= a.emission_phase2_FRM_TTGHG2		* b.Phase_II_FRM_Reduction;

# Conversion to Annual Metric Tonne
UPDATE emfac2014_ghg_ei_statewide_phase2 a INNER JOIN operation_days b USING (Veh_Class)
SET a.VMT							=a.VMT								*b.days,
	a.emission						=a.emission							*b.days*0.907185,
	a.emission_phase_1				=a.emission_phase_1					*b.days*0.907185,
    a.emission_phase2_alt3			=a.emission_phase2_alt3				*b.days*0.907185,
    a.emission_phase2_alt4			=a.emission_phase2_alt4				*b.days*0.907185,
    a.emission_phase2_FRM			=a.emission_phase2_FRM				*b.days*0.907185,
    a.emission_phase2_FRM_wo_trailer=a.emission_phase2_FRM_wo_trailer	*b.days*0.907185,
    a.emission_phase2_FRM_TTGHG2	=a.emission_phase2_FRM_TTGHG2		*b.days*0.907185;

# Summary
SELECT cal_year,Veh_Type,Model_Year,
sum(VMT) AS VMT,
sum(emission) As emission, 
sum(emission_phase_1) AS emission_phase_1,
sum(emission_phase2_alt3) AS emission_phase2_alt3, 
sum(emission_phase2_alt4) AS emission_phase2_alt4,
sum(emission_phase2_FRM) AS emission_phase2_FRM,
sum(emission_phase2_FRM_wo_trailer) AS emission_phase2_FRM_wo_trailer,
sum(emission_phase2_FRM_TTGHG2) AS emission_phase2_FRM_TTGHG2 
FROM arb_ghg_phase2.emfac2014_ghg_ei_statewide_phase2
GROUP BY cal_year,Veh_Type,Model_Year
LIMIT 0,100000;